"""
Created on Mon Mar 17 17:35:12 2020

@author: xczcx

@email:2292879219@qq.com
"""

**Project description**
 A tool to transform TEXT to VEC
 input = DataFrame, Title Name
 output = DataFrame transformed

env needed:
importlib-metadata @ file:///C:/ci/importlib-metadata_1593446525189/work
numpy==1.19.2
openpyxl==3.0.5
pandas==1.1.3
six==1.15.0
sklearn==0.0
torch==1.7.0
torchaudio==0.7.0
torchvision==0.8.1
tqdm @ file:///tmp/build/80754af9/tqdm_1602185206534/work
urllib3==1.26.2
requests==2.25.0

